@@ -71,7 +71,7 @@ class Payment:
         # return ok(_format(r.json()))
         filters = {'siteOperationId':payment_id}
         r = requests.get(self.url + '/payments', params=filters, headers=self.headers)
-        list_results = r['response']['results']
+        list_results = r.json()['response']['results']
         if len(list_results) == 1:
             return _format(list_results[0])
         else:
